# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: machinetalk/protobuf/types.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from machinetalk.protobuf import nanopb_pb2 as machinetalk_dot_protobuf_dot_nanopb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='machinetalk/protobuf/types.proto',
  package='machinetalk',
  syntax='proto2',
  serialized_pb=_b('\n machinetalk/protobuf/types.proto\x12\x0bmachinetalk\x1a!machinetalk/protobuf/nanopb.proto*\xf7\x01\n\tValueType\x12\x0b\n\x07HAL_BIT\x10\x01\x12\r\n\tHAL_FLOAT\x10\x02\x12\x0b\n\x07HAL_S32\x10\x03\x12\x0b\n\x07HAL_U32\x10\x04\x12\x0b\n\x07HAL_S64\x10\x05\x12\x0b\n\x07HAL_U64\x10\x06\x12\n\n\x06STRING\x10\x07\x12\t\n\x05\x42YTES\x10\x08\x12\t\n\x05INT32\x10\x14\x12\n\n\x06UINT32\x10\x1e\x12\t\n\x05INT64\x10(\x12\n\n\x06UINT64\x10\x32\x12\n\n\x06\x44OUBLE\x10<\x12\x08\n\x04\x42OOL\x10P\x12\r\n\tCARTESIAN\x10\x64\x12\x14\n\x10LEGACY_CARTESIAN\x10n\x12\x08\n\x04POSE\x10x\x12\x10\n\x0bLEGACY_POSE\x10\x82\x01*6\n\x0fHalPinDirection\x12\n\n\x06HAL_IN\x10\x10\x12\x0b\n\x07HAL_OUT\x10 \x12\n\n\x06HAL_IO\x10\x30*,\n\x11HalParamDirection\x12\n\n\x06HAL_RO\x10@\x12\x0b\n\x06HAL_RW\x10\xc0\x01*M\n\x0cHalFunctType\x12\x18\n\x14\x46S_LEGACY_THREADFUNC\x10\x00\x12\x12\n\x0e\x46S_XTHREADFUNC\x10\x01\x12\x0f\n\x0b\x46S_USERLAND\x10\x02*\xdb\x01\n\nObjectType\x12\x16\n\x12HAL_OBJECT_INVALID\x10\x00\x12\x0b\n\x07HAL_PIN\x10\x01\x12\x0e\n\nHAL_SIGNAL\x10\x02\x12\r\n\tHAL_PARAM\x10\x03\x12\x0e\n\nHAL_THREAD\x10\x04\x12\r\n\tHAL_FUNCT\x10\x05\x12\x11\n\rHAL_COMPONENT\x10\x06\x12\x0e\n\nHAL_VTABLE\x10\x07\x12\x0c\n\x08HAL_INST\x10\x08\x12\x0c\n\x08HAL_RING\x10\t\x12\r\n\tHAL_GROUP\x10\n\x12\x0e\n\nHAL_MEMBER\x10\x0b\x12\x0c\n\x08HAL_PLUG\x10\x0c*\x81\x01\n\tmsgidType\x12\x0e\n\tMSGID_MAX\x10\xa0\x1f\x12\x1a\n\x15MSGID_ROUTE_DELIMITER\x10\xa1\x1f\x12\x14\n\x0fMSGID_ERROR_MSG\x10\xa2\x1f\x12\x0f\n\nMSGID_BLOB\x10\xa3\x1f\x12\x11\n\x0cMSGID_STRING\x10\xa4\x1f\x12\x0e\n\tMSGID_HOP\x10\xa5\x1f*\xee\x01\n\nsocketType\x12\x0f\n\x0bST_ZMQ_PAIR\x10\x00\x12\x0e\n\nST_ZMQ_PUB\x10\x01\x12\x0e\n\nST_ZMQ_SUB\x10\x02\x12\x0e\n\nST_ZMQ_REQ\x10\x03\x12\x0e\n\nST_ZMQ_REP\x10\x04\x12\x11\n\rST_ZMQ_DEALER\x10\x05\x12\x11\n\rST_ZMQ_ROUTER\x10\x06\x12\x0f\n\x0bST_ZMQ_PULL\x10\x07\x12\x0f\n\x0bST_ZMQ_PUSH\x10\x08\x12\x0f\n\x0bST_ZMQ_XPUB\x10\t\x12\x0f\n\x0bST_ZMQ_XSUB\x10\n\x12\x11\n\rST_ZMQ_STREAM\x10\x0b\x12\x12\n\x0eST_ZMQ_INVALID\x10\x0f*b\n\x11securityMechanism\x12\x18\n\x0bSM_ZMQ_NONE\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x0f\n\x0bSM_ZMQ_NULL\x10\x00\x12\x10\n\x0cSM_ZMQ_PLAIN\x10\x01\x12\x10\n\x0cSM_ZMQ_CURVE\x10\x02*l\n\nRCS_STATUS\x12!\n\x14UNINITIALIZED_STATUS\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x0c\n\x08RCS_DONE\x10\x01\x12\x0c\n\x08RCS_EXEC\x10\x02\x12\r\n\tRCS_ERROR\x10\x03\x12\x10\n\x0cRCS_RECEIVED\x10\x04*:\n\tMsgOrigin\x12\x0e\n\nMSG_KERNEL\x10\x00\x12\x0e\n\nMSG_RTUSER\x10\x01\x12\r\n\tMSG_ULAPI\x10\x02*\x7f\n\x08MsgLevel\x12\x12\n\x0eRTAPI_MSG_NONE\x10\x00\x12\x11\n\rRTAPI_MSG_ERR\x10\x01\x12\x12\n\x0eRTAPI_MSG_WARN\x10\x02\x12\x12\n\x0eRTAPI_MSG_INFO\x10\x03\x12\x11\n\rRTAPI_MSG_DBG\x10\x04\x12\x11\n\rRTAPI_MSG_ALL\x10\x05*\xa0\x01\n\x0cOriginDetail\x12\x0f\n\x0bUNIX_SIGNAL\x10\n\x12\x15\n\x11INSTANCE_SHUTDOWN\x10\x14\x12\x0e\n\nZMQ_SOCKET\x10\x46\x12\r\n\tNML_LAYER\x10P\x12\r\n\tRCS_LAYER\x10Z\x12\r\n\tCMS_LAYER\x10\x64\x12\x0c\n\x08IP_LAYER\x10n\x12\r\n\tTCP_LAYER\x10x\x12\x0e\n\tPGM_LAYER\x10\x82\x01*\xa5\x01\n\nOriginType\x12\x0b\n\x07PROCESS\x10\n\x12\x0f\n\x0bUSER_THREAD\x10\x14\x12\r\n\tRT_THREAD\x10\x1e\x12\r\n\tCOMPONENT\x10(\x12\x13\n\x0fTHREAD_FUNCTION\x10\x32\x12\x12\n\x0e\x43OMPONENT_INIT\x10<\x12\x12\n\x0e\x43OMPONENT_EXIT\x10\x46\x12\t\n\x05GROUP\x10P\x12\x07\n\x03PIN\x10Z\x12\n\n\x06SIGNAL\x10\x64*:\n\x08Severity\x12\x13\n\x0fS_INFORMATIONAL\x10\x01\x12\r\n\tS_WARNING\x10\x02\x12\n\n\x06S_FAIL\x10\x04*D\n\nStatusType\x12\x0c\n\x08\x45NQUEUED\x10\x01\x12\x0e\n\nPROCESSING\x10\x02\x12\x0c\n\x08\x43OMPLETE\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04*Y\n\tReplyType\x12\x08\n\x04NONE\x10\x00\x12\x10\n\x0cON_RECEPTION\x10\x01\x12\r\n\tON_QUEUED\x10\x02\x12\x11\n\rON_COMPLETION\x10\x04\x12\x0e\n\tALL_STEPS\x10\xff\x01*\xd6\x02\n\x0bServiceType\x12\x0e\n\nST_LOGGING\x10\x01\x12\r\n\tST_CONFIG\x10\x02\x12\x0c\n\x08ST_REDIS\x10\x03\x12\x0b\n\x07ST_HTTP\x10\x04\x12\x0c\n\x08ST_HTTPS\x10\x05\x12\x10\n\x0cST_WEBSOCKET\x10\x06\x12\x11\n\rST_WEBSOCKETS\x10\x07\x12\x14\n\x10ST_RTAPI_COMMAND\x10\x08\x12\x13\n\x0fST_STP_HALGROUP\x10\t\x12\x13\n\x0fST_STP_HALRCOMP\x10\n\x12\x11\n\rST_STP_INTERP\x10\x0b\x12\x0f\n\x0bST_STP_TASK\x10\x0c\x12\x13\n\x0fST_HAL_RCOMMAND\x10\r\x12\x13\n\x0fST_TASK_COMMAND\x10\x0e\x12\x15\n\x11ST_INTERP_COMMAND\x10\x0f\x12\x19\n\x15ST_MESSAGEBUS_COMMAND\x10\x10\x12\x1a\n\x16ST_MESSAGEBUS_RESPONSE\x10\x11*1\n\nServiceAPI\x12\x13\n\x0fSA_ZMQ_PROTOBUF\x10\x01\x12\x0e\n\nSA_WS_JSON\x10\x02*\x9f\x46\n\rContainerType\x12\x10\n\x0cMT_RTMESSAGE\x10\x02\x12\r\n\tMT_MOTCMD\x10\x03\x12\x10\n\x0cMT_MOTSTATUS\x10\x04\x12\x14\n\x10MT_LEGACY_MOTCMD\x10\x05\x12\x17\n\x13MT_LEGACY_MOTSTATUS\x10\x06\x12\n\n\x06MT_WOU\x10\x07\x12\x10\n\x0cMT_HALUPDATE\x10\x08\x12\x14\n\x10MT_RTAPI_MESSAGE\x10\t\x12\x12\n\x0eMT_LOG_MESSAGE\x10\n\x12\x0e\n\nMT_PREVIEW\x10\x0b\x12\x0f\n\x0bMT_PROGRESS\x10\x0c\x12\x12\n\x0eMT_INTERP_STAT\x10\r\x12\r\n\tMT_SYSLOG\x10\x12\x12\x11\n\rMT_LEGACY_NML\x10\x13\x12\x17\n\x13MT_LEGACY_MOTCONFIG\x10\x14\x12\x16\n\x12MT_STP_UPDATE_FULL\x10\x1a\x12\x11\n\rMT_STP_UPDATE\x10\x1c\x12\x12\n\x0eMT_STP_NOGROUP\x10\x1b\x12\x0f\n\x0bMT_SHUTDOWN\x10-\x12\x17\n\x13MT_CONFIRM_SHUTDOWN\x10\x32\x12\x11\n\rMT_RTMESSAGE0\x10\x1e\x12\x11\n\rMT_RTMESSAGE1\x10\x1f\x12\x11\n\rMT_RTMESSAGE2\x10 \x12\x11\n\rMT_RTMESSAGE3\x10!\x12\x11\n\rMT_RTMESSAGE4\x10\"\x12\x0c\n\x08MT_ASCII\x10\x64\x12\x0e\n\nMT_UNICODE\x10\x65\x12\x0c\n\x08MT_GCODE\x10\x66\x12\r\n\tMT_PYTHON\x10g\x12\r\n\tMT_PICKLE\x10h\x12\n\n\x06MT_TCL\x10i\x12\n\n\x06MT_XML\x10j\x12\x0b\n\x07MT_JSON\x10k\x12\x0b\n\x07MT_JPEG\x10l\x12\n\n\x06MT_PNG\x10m\x12\x0b\n\x07MT_TIFF\x10n\x12\x11\n\rMT_POSTSCRIPT\x10o\x12\n\n\x06MT_SVG\x10p\x12\x15\n\x10MT_ZMQ_SUBSCRIBE\x10\x96\x01\x12\x17\n\x12MT_ZMQ_UNSUBSCRIBE\x10\x97\x01\x12\x0c\n\x07MT_PING\x10\xd2\x01\x12\x18\n\x13MT_PING_ACKNOWLEDGE\x10\xd7\x01\x12\x0e\n\tMT_REJECT\x10\xdc\x01\x12\x0c\n\x07MT_DONE\x10\xf0\x01\x12\x17\n\x12MT_SERVICE_REQUEST\x10\xfa\x01\x12\x1c\n\x17MT_SERVICE_ANNOUNCEMENT\x10\xfb\x01\x12\x15\n\x10MT_SERVICE_PROBE\x10\xfc\x01\x12!\n\x1cMT_MESSAGEBUS_NO_DESTINATION\x10\xff\x01\x12\x15\n\x10MT_HALRCOMP_BIND\x10\x80\x02\x12\x1d\n\x18MT_HALRCOMP_BIND_CONFIRM\x10\x81\x02\x12\x1c\n\x17MT_HALRCOMP_BIND_REJECT\x10\x82\x02\x12\x14\n\x0fMT_HALRCOMP_SET\x10\x83\x02\x12\x1b\n\x16MT_HALRCOMP_SET_REJECT\x10\x84\x02\x12\x14\n\x0fMT_HALRCOMP_ACK\x10\x87\x02\x12\x17\n\x12MT_HALRCOMMAND_SET\x10\x89\x02\x12\x1e\n\x19MT_HALRCOMMAND_SET_REJECT\x10\x8a\x02\x12\x17\n\x12MT_HALRCOMMAND_GET\x10\x8b\x02\x12\x1e\n\x19MT_HALRCOMMAND_GET_REJECT\x10\x8c\x02\x12\x1a\n\x15MT_HALRCOMMAND_CREATE\x10\x8d\x02\x12!\n\x1cMT_HALRCOMMAND_CREATE_REJECT\x10\x8e\x02\x12\x1a\n\x15MT_HALRCOMMAND_DELETE\x10\x8f\x02\x12!\n\x1cMT_HALRCOMMAND_DELETE_REJECT\x10\x90\x02\x12\x17\n\x12MT_HALRCOMMAND_ACK\x10\x91\x02\x12\x19\n\x14MT_HALRCOMMAND_ERROR\x10\x92\x02\x12\x1c\n\x17MT_HALRCOMMAND_DESCRIBE\x10\x94\x02\x12\x1f\n\x1aMT_HALRCOMMAND_DESCRIPTION\x10\x95\x02\x12\x1c\n\x17MT_HALRCOMP_FULL_UPDATE\x10\xa0\x02\x12#\n\x1eMT_HALRCOMP_INCREMENTAL_UPDATE\x10\xa1\x02\x12\x16\n\x11MT_HALRCOMP_ERROR\x10\xa2\x02\x12\x15\n\x10MT_HALGROUP_BIND\x10\xa6\x02\x12\x1d\n\x18MT_HALGROUP_BIND_CONFIRM\x10\xa7\x02\x12\x1c\n\x17MT_HALGROUP_BIND_REJECT\x10\xa8\x02\x12\x1c\n\x17MT_HALGROUP_FULL_UPDATE\x10\xa9\x02\x12#\n\x1eMT_HALGROUP_INCREMENTAL_UPDATE\x10\xaa\x02\x12\x16\n\x11MT_HALGROUP_ERROR\x10\xab\x02\x12\x16\n\x11MT_RTAPI_APP_EXIT\x10\xac\x02\x12\x16\n\x11MT_RTAPI_APP_PING\x10\xad\x02\x12\x18\n\x13MT_RTAPI_APP_LOADRT\x10\xae\x02\x12\x15\n\x10MT_RTAPI_APP_LOG\x10\xaf\x02\x12\x1a\n\x15MT_RTAPI_APP_UNLOADRT\x10\xb1\x02\x12\x19\n\x14MT_RTAPI_APP_NEWINST\x10\xb2\x02\x12\x1b\n\x16MT_RTAPI_APP_NEWTHREAD\x10\xb3\x02\x12\x1b\n\x16MT_RTAPI_APP_DELTHREAD\x10\xb4\x02\x12\x1a\n\x15MT_RTAPI_APP_CALLFUNC\x10\xb5\x02\x12\x17\n\x12MT_RTAPI_APP_REPLY\x10\xb6\x02\x12\x19\n\x14MT_RTAPI_APP_DELINST\x10\xb7\x02\x12\x19\n\x14MT_LIST_APPLICATIONS\x10\xde\x02\x12\x1c\n\x17MT_DESCRIBE_APPLICATION\x10\xdf\x02\x12\x1c\n\x17MT_RETRIEVE_APPLICATION\x10\xe0\x02\x12\x1a\n\x15MT_APPLICATION_DETAIL\x10\xe1\x02\x12\r\n\x08MT_ERROR\x10\xe8\x02\x12\x13\n\x0eMT_FULL_UPDATE\x10\xf2\x02\x12\x1a\n\x15MT_INCREMENTAL_UPDATE\x10\xf3\x02\x12\x12\n\rMT_TASK_REPLY\x10\x90\x03\x12\x15\n\x10MT_TICKET_UPDATE\x10\x91\x03\x12\x15\n\x10MT_CREDIT_UPDATE\x10\xc2\x03\x12\x14\n\x0fMT_EMCMOT_LOWER\x10\xe8\x07\x12\x14\n\x0fMT_EMCMOT_UPPER\x10\xcc\x08\x12\x14\n\x0fMT_EMCMOT_ABORT\x10\xe9\x07\x12\x19\n\x14MT_EMCMOT_AXIS_ABORT\x10\xea\x07\x12\x15\n\x10MT_EMCMOT_ENABLE\x10\xeb\x07\x12\x16\n\x11MT_EMCMOT_DISABLE\x10\xec\x07\x12\x1f\n\x1aMT_EMCMOT_ENABLE_AMPLIFIER\x10\xed\x07\x12 \n\x1bMT_EMCMOT_DISABLE_AMPLIFIER\x10\xee\x07\x12\x1e\n\x19MT_EMCMOT_ENABLE_WATCHDOG\x10\xef\x07\x12\x1f\n\x1aMT_EMCMOT_DISABLE_WATCHDOG\x10\xf0\x07\x12\x1d\n\x18MT_EMCMOT_ACTIVATE_JOINT\x10\xf1\x07\x12\x1f\n\x1aMT_EMCMOT_DEACTIVATE_JOINT\x10\xf2\x07\x12\x14\n\x0fMT_EMCMOT_PAUSE\x10\xf3\x07\x12\x15\n\x10MT_EMCMOT_RESUME\x10\xf4\x07\x12\x13\n\x0eMT_EMCMOT_STEP\x10\xf5\x07\x12\x13\n\x0eMT_EMCMOT_FREE\x10\xf6\x07\x12\x14\n\x0fMT_EMCMOT_COORD\x10\xf7\x07\x12\x15\n\x10MT_EMCMOT_TELEOP\x10\xf8\x07\x12\x1c\n\x17MT_EMCMOT_SPINDLE_SCALE\x10\xf9\x07\x12\x18\n\x13MT_EMCMOT_SS_ENABLE\x10\xfa\x07\x12\x19\n\x14MT_EMCMOT_FEED_SCALE\x10\xfb\x07\x12\x18\n\x13MT_EMCMOT_FS_ENABLE\x10\xfc\x07\x12\x18\n\x13MT_EMCMOT_FH_ENABLE\x10\xfd\x07\x12\x18\n\x13MT_EMCMOT_AF_ENABLE\x10\xfe\x07\x12\x1e\n\x19MT_EMCMOT_OVERRIDE_LIMITS\x10\xff\x07\x12\x13\n\x0eMT_EMCMOT_HOME\x10\x80\x08\x12\x15\n\x10MT_EMCMOT_UNHOME\x10\x81\x08\x12\x17\n\x12MT_EMCMOT_JOG_CONT\x10\x82\x08\x12\x17\n\x12MT_EMCMOT_JOG_INCR\x10\x83\x08\x12\x16\n\x11MT_EMCMOT_JOG_ABS\x10\x84\x08\x12\x17\n\x12MT_EMCMOT_SET_LINE\x10\x85\x08\x12\x19\n\x14MT_EMCMOT_SET_CIRCLE\x10\x86\x08\x12 \n\x1bMT_EMCMOT_SET_TELEOP_VECTOR\x10\x87\x08\x12 \n\x1bMT_EMCMOT_CLEAR_PROBE_FLAGS\x10\x88\x08\x12\x14\n\x0fMT_EMCMOT_PROBE\x10\x89\x08\x12\x18\n\x13MT_EMCMOT_RIGID_TAP\x10\x8a\x08\x12\"\n\x1dMT_EMCMOT_SET_POSITION_LIMITS\x10\x8b\x08\x12\x1b\n\x16MT_EMCMOT_SET_BACKLASH\x10\x8c\x08\x12\x1d\n\x18MT_EMCMOT_SET_MIN_FERROR\x10\x8d\x08\x12\x1d\n\x18MT_EMCMOT_SET_MAX_FERROR\x10\x8e\x08\x12\x16\n\x11MT_EMCMOT_SET_VEL\x10\x8f\x08\x12\x1c\n\x17MT_EMCMOT_SET_VEL_LIMIT\x10\x90\x08\x12\"\n\x1dMT_EMCMOT_SET_JOINT_VEL_LIMIT\x10\x91\x08\x12\"\n\x1dMT_EMCMOT_SET_JOINT_ACC_LIMIT\x10\x92\x08\x12\x16\n\x11MT_EMCMOT_SET_ACC\x10\x93\x08\x12\x1c\n\x17MT_EMCMOT_SET_TERM_COND\x10\x94\x08\x12\x1b\n\x16MT_EMCMOT_SET_NUM_AXES\x10\x95\x08\x12\x1d\n\x18MT_EMCMOT_SET_WORLD_HOME\x10\x96\x08\x12 \n\x1bMT_EMCMOT_SET_HOMING_PARAMS\x10\x97\x08\x12\x18\n\x13MT_EMCMOT_SET_DEBUG\x10\x98\x08\x12\x17\n\x12MT_EMCMOT_SET_DOUT\x10\x99\x08\x12\x17\n\x12MT_EMCMOT_SET_AOUT\x10\x9a\x08\x12\x1e\n\x19MT_EMCMOT_SET_SPINDLESYNC\x10\x9b\x08\x12\x19\n\x14MT_EMCMOT_SPINDLE_ON\x10\x9c\x08\x12\x1a\n\x15MT_EMCMOT_SPINDLE_OFF\x10\x9d\x08\x12\x1f\n\x1aMT_EMCMOT_SPINDLE_INCREASE\x10\x9e\x08\x12\x1f\n\x1aMT_EMCMOT_SPINDLE_DECREASE\x10\x9f\x08\x12#\n\x1eMT_EMCMOT_SPINDLE_BRAKE_ENGAGE\x10\xa0\x08\x12$\n\x1fMT_EMCMOT_SPINDLE_BRAKE_RELEASE\x10\xa1\x08\x12\x1f\n\x1aMT_EMCMOT_SET_MOTOR_OFFSET\x10\xa2\x08\x12\x1d\n\x18MT_EMCMOT_SET_JOINT_COMP\x10\xa3\x08\x12\x19\n\x14MT_EMCMOT_SET_OFFSET\x10\xa4\x08\x12\x19\n\x14MT_EMCMOT_COMMAND_OK\x10\xa5\x08\x12&\n!MT_EMCMOT_COMMAND_UNKNOWN_COMMAND\x10\xa6\x08\x12&\n!MT_EMCMOT_COMMAND_INVALID_COMMAND\x10\xa7\x08\x12%\n MT_EMCMOT_COMMAND_INVALID_PARAMS\x10\xa8\x08\x12\x1f\n\x1aMT_EMCMOT_COMMAND_BAD_EXEC\x10\xa9\x08\x12\x1e\n\x19MT_EMCMOT_MOTION_DISABLED\x10\xaa\x08\x12\x1a\n\x15MT_EMCMOT_MOTION_FREE\x10\xab\x08\x12\x1c\n\x17MT_EMCMOT_MOTION_TELEOP\x10\xac\x08\x12\x1b\n\x16MT_EMCMOT_MOTION_COORD\x10\xad\x08\x12\x19\n\x14MT_EMCMOT_JOINT_FLAG\x10\xae\x08\x12\x1a\n\x15MT_EMCMOT_MOTION_FLAG\x10\xaf\x08\x12\x14\n\x0fMT_PRU_FIRMWARE\x10\x80\x10\x12\x1a\n\x15MT_MESA_5I20_FIRMWARE\x10\xb8\x17\x12\x0c\n\x07MT_BLOB\x10\xa0\x1f\x12\r\n\x08MT_TEST1\x10\x89\'\x12\r\n\x08MT_TEST2\x10\x8a\'\x12\r\n\x08MT_TEST3\x10\x8b\'\x12\x15\n\x10MT_EMC_NML_LOWER\x10\x90N\x12\x15\n\x10MT_EMC_NML_UPPER\x10\xc8\x65\x12\x1a\n\x15MT_EMC_OPERATOR_ERROR\x10\x9bN\x12\x19\n\x14MT_EMC_OPERATOR_TEXT\x10\x9cN\x12\x1c\n\x17MT_EMC_OPERATOR_DISPLAY\x10\x9dN\x12\x10\n\x0bMT_EMC_NULL\x10\xa5N\x12\x15\n\x10MT_EMC_SET_DEBUG\x10\xa6N\x12\x16\n\x11MT_EMC_SYSTEM_CMD\x10\xaeN\x12\x19\n\x14MT_EMC_AXIS_SET_AXIS\x10\xf5N\x12\x1a\n\x15MT_EMC_AXIS_SET_UNITS\x10\xf6N\x12\'\n\"MT_EMC_AXIS_SET_MIN_POSITION_LIMIT\x10\xfbN\x12\'\n\"MT_EMC_AXIS_SET_MAX_POSITION_LIMIT\x10\xfcN\x12\x1d\n\x18MT_EMC_TOOL_START_CHANGE\x10\xd6\x08\x12\x1c\n\x17MT_EMC_EXEC_PLUGIN_CALL\x10\xd8\x08\x12\x1a\n\x15MT_EMC_IO_PLUGIN_CALL\x10\xd9\x08\x12\x1b\n\x16MT_EMC_AXIS_SET_FERROR\x10\xffN\x12\"\n\x1dMT_EMC_AXIS_SET_HOMING_PARAMS\x10\x80O\x12\x1f\n\x1aMT_EMC_AXIS_SET_MIN_FERROR\x10\x83O\x12!\n\x1cMT_EMC_AXIS_SET_MAX_VELOCITY\x10\x84O\x12\x15\n\x10MT_EMC_AXIS_INIT\x10\x86O\x12\x15\n\x10MT_EMC_AXIS_HALT\x10\x87O\x12\x16\n\x11MT_EMC_AXIS_ABORT\x10\x88O\x12\x17\n\x12MT_EMC_AXIS_ENABLE\x10\x89O\x12\x18\n\x13MT_EMC_AXIS_DISABLE\x10\x8aO\x12\x15\n\x10MT_EMC_AXIS_HOME\x10\x8bO\x12\x17\n\x12MT_EMC_AXIS_UNHOME\x10\x97O\x12\x14\n\x0fMT_EMC_AXIS_JOG\x10\x8cO\x12\x19\n\x14MT_EMC_AXIS_INCR_JOG\x10\x8dO\x12\x18\n\x13MT_EMC_AXIS_ABS_JOG\x10\x8eO\x12\x19\n\x14MT_EMC_AXIS_ACTIVATE\x10\x8fO\x12\x1b\n\x16MT_EMC_AXIS_DEACTIVATE\x10\x90O\x12 \n\x1bMT_EMC_AXIS_OVERRIDE_LIMITS\x10\x91O\x12\x1a\n\x15MT_EMC_AXIS_LOAD_COMP\x10\x93O\x12\x1d\n\x18MT_EMC_AXIS_SET_BACKLASH\x10\x96O\x12\x15\n\x10MT_EMC_AXIS_STAT\x10\xd7O\x12\x19\n\x14MT_EMC_TRAJ_SET_AXES\x10\xd9O\x12\x1a\n\x15MT_EMC_TRAJ_SET_UNITS\x10\xdaO\x12\x1f\n\x1aMT_EMC_TRAJ_SET_CYCLE_TIME\x10\xdbO\x12\x19\n\x14MT_EMC_TRAJ_SET_MODE\x10\xdcO\x12\x1d\n\x18MT_EMC_TRAJ_SET_VELOCITY\x10\xddO\x12!\n\x1cMT_EMC_TRAJ_SET_ACCELERATION\x10\xdeO\x12!\n\x1cMT_EMC_TRAJ_SET_MAX_VELOCITY\x10\xdfO\x12%\n MT_EMC_TRAJ_SET_MAX_ACCELERATION\x10\xe0O\x12\x1a\n\x15MT_EMC_TRAJ_SET_SCALE\x10\xe1O\x12\x1e\n\x19MT_EMC_TRAJ_SET_MOTION_ID\x10\xe2O\x12\x15\n\x10MT_EMC_TRAJ_INIT\x10\xe3O\x12\x15\n\x10MT_EMC_TRAJ_HALT\x10\xe4O\x12\x17\n\x12MT_EMC_TRAJ_ENABLE\x10\xe5O\x12\x18\n\x13MT_EMC_TRAJ_DISABLE\x10\xe6O\x12\x16\n\x11MT_EMC_TRAJ_ABORT\x10\xe7O\x12\x16\n\x11MT_EMC_TRAJ_PAUSE\x10\xe8O\x12\x15\n\x10MT_EMC_TRAJ_STEP\x10\xe9O\x12\x17\n\x12MT_EMC_TRAJ_RESUME\x10\xeaO\x12\x16\n\x11MT_EMC_TRAJ_DELAY\x10\xebO\x12\x1c\n\x17MT_EMC_TRAJ_LINEAR_MOVE\x10\xecO\x12\x1e\n\x19MT_EMC_TRAJ_CIRCULAR_MOVE\x10\xedO\x12\x1e\n\x19MT_EMC_TRAJ_SET_TERM_COND\x10\xeeO\x12\x1b\n\x16MT_EMC_TRAJ_SET_OFFSET\x10\xefO\x12\x18\n\x13MT_EMC_TRAJ_SET_G5X\x10\xf0O\x12\x19\n\x14MT_EMC_TRAJ_SET_HOME\x10\xf1O\x12\x1d\n\x18MT_EMC_TRAJ_SET_ROTATION\x10\xf2O\x12\x18\n\x13MT_EMC_TRAJ_SET_G92\x10\xf3O\x12)\n$MT_EMC_TRAJ_CLEAR_PROBE_TRIPPED_FLAG\x10\xf4O\x12\x16\n\x11MT_EMC_TRAJ_PROBE\x10\xf5O\x12\"\n\x1dMT_EMC_TRAJ_SET_TELEOP_ENABLE\x10\xf6O\x12\"\n\x1dMT_EMC_TRAJ_SET_TELEOP_VECTOR\x10\xf7O\x12 \n\x1bMT_EMC_TRAJ_SET_SPINDLESYNC\x10\xf8O\x12\"\n\x1dMT_EMC_TRAJ_SET_SPINDLE_SCALE\x10\xf9O\x12\x1e\n\x19MT_EMC_TRAJ_SET_FO_ENABLE\x10\xfaO\x12\x1e\n\x19MT_EMC_TRAJ_SET_SO_ENABLE\x10\xfbO\x12\x1e\n\x19MT_EMC_TRAJ_SET_FH_ENABLE\x10\xfcO\x12\x1a\n\x15MT_EMC_TRAJ_RIGID_TAP\x10\xfdO\x12 \n\x1bMT_EMC_TRAJ_SET_RAPID_SCALE\x10\xfeO\x12\x15\n\x10MT_EMC_TRAJ_STAT\x10\xbbP\x12\x17\n\x12MT_EMC_MOTION_INIT\x10\xbdP\x12\x17\n\x12MT_EMC_MOTION_HALT\x10\xbeP\x12\x18\n\x13MT_EMC_MOTION_ABORT\x10\xbfP\x12\x1b\n\x16MT_EMC_MOTION_SET_AOUT\x10\xc0P\x12\x1b\n\x16MT_EMC_MOTION_SET_DOUT\x10\xc1P\x12\x1b\n\x16MT_EMC_MOTION_ADAPTIVE\x10\xc2P\x12\x1a\n\x15MT_EMC_SPINDLE_ORIENT\x10\xcdP\x12(\n#MT_EMC_SPINDLE_WAIT_ORIENT_COMPLETE\x10\xceP\x12\x17\n\x12MT_EMC_MOTION_STAT\x10\x9fQ\x12\x15\n\x10MT_EMC_TASK_INIT\x10\x85R\x12\x15\n\x10MT_EMC_TASK_HALT\x10\x86R\x12\x16\n\x11MT_EMC_TASK_ABORT\x10\x87R\x12\x19\n\x14MT_EMC_TASK_SET_MODE\x10\x88R\x12\x1a\n\x15MT_EMC_TASK_SET_STATE\x10\x89R\x12\x1a\n\x15MT_EMC_TASK_PLAN_OPEN\x10\x8aR\x12\x19\n\x14MT_EMC_TASK_PLAN_RUN\x10\x8bR\x12\x1a\n\x15MT_EMC_TASK_PLAN_READ\x10\x8cR\x12\x1d\n\x18MT_EMC_TASK_PLAN_EXECUTE\x10\x8dR\x12\x1b\n\x16MT_EMC_TASK_PLAN_PAUSE\x10\x8eR\x12\x1a\n\x15MT_EMC_TASK_PLAN_STEP\x10\x8fR\x12\x1c\n\x17MT_EMC_TASK_PLAN_RESUME\x10\x90R\x12\x19\n\x14MT_EMC_TASK_PLAN_END\x10\x91R\x12\x1b\n\x16MT_EMC_TASK_PLAN_CLOSE\x10\x92R\x12\x1a\n\x15MT_EMC_TASK_PLAN_INIT\x10\x93R\x12\x1b\n\x16MT_EMC_TASK_PLAN_SYNCH\x10\x94R\x12\'\n\"MT_EMC_TASK_PLAN_SET_OPTIONAL_STOP\x10\x95R\x12&\n!MT_EMC_TASK_PLAN_SET_BLOCK_DELETE\x10\x96R\x12#\n\x1eMT_EMC_TASK_PLAN_OPTIONAL_STOP\x10\x97R\x12\x1b\n\x16MT_EMC_TASK_PLAN_RESET\x10\x98R\x12\x1b\n\x16MT_EMC_TASK_PLAN_REPLY\x10\xa2R\x12\x15\n\x10MT_EMC_TASK_STAT\x10\xe7R\x12\x15\n\x10MT_EMC_TOOL_INIT\x10\xddV\x12\x15\n\x10MT_EMC_TOOL_HALT\x10\xdeV\x12\x16\n\x11MT_EMC_TOOL_ABORT\x10\xdfV\x12\x18\n\x13MT_EMC_TOOL_PREPARE\x10\xe0V\x12\x15\n\x10MT_EMC_TOOL_LOAD\x10\xe1V\x12\x17\n\x12MT_EMC_TOOL_UNLOAD\x10\xe2V\x12 \n\x1bMT_EMC_TOOL_LOAD_TOOL_TABLE\x10\xe3V\x12\x1b\n\x16MT_EMC_TOOL_SET_OFFSET\x10\xe4V\x12\x1b\n\x16MT_EMC_TOOL_SET_NUMBER\x10\xe5V\x12\"\n\x1dMT_EMC_TOOL_UPDATE_TOOL_TABLE\x10\xe6V\x12\x15\n\x10MT_EMC_TOOL_STAT\x10\xbfW\x12\x18\n\x13MT_EMC_AUX_ESTOP_ON\x10\xc6W\x12\x19\n\x14MT_EMC_AUX_ESTOP_OFF\x10\xc7W\x12\x1b\n\x16MT_EMC_AUX_ESTOP_RESET\x10\xc8W\x12\x1a\n\x15MT_EMC_AUX_INPUT_WAIT\x10\xc9W\x12\x14\n\x0fMT_EMC_AUX_STAT\x10\xa3X\x12\x16\n\x11MT_EMC_SPINDLE_ON\x10\xa8X\x12\x17\n\x12MT_EMC_SPINDLE_OFF\x10\xa9X\x12\x1c\n\x17MT_EMC_SPINDLE_INCREASE\x10\xadX\x12\x1c\n\x17MT_EMC_SPINDLE_DECREASE\x10\xaeX\x12\x1c\n\x17MT_EMC_SPINDLE_CONSTANT\x10\xafX\x12!\n\x1cMT_EMC_SPINDLE_BRAKE_RELEASE\x10\xb0X\x12 \n\x1bMT_EMC_SPINDLE_BRAKE_ENGAGE\x10\xb1X\x12\x19\n\x14MT_EMC_SPINDLE_SPEED\x10\xb4X\x12\x18\n\x13MT_EMC_SPINDLE_STAT\x10\x87Y\x12\x1b\n\x16MT_EMC_COOLANT_MIST_ON\x10\x8cY\x12\x1c\n\x17MT_EMC_COOLANT_MIST_OFF\x10\x8dY\x12\x1c\n\x17MT_EMC_COOLANT_FLOOD_ON\x10\x8eY\x12\x1d\n\x18MT_EMC_COOLANT_FLOOD_OFF\x10\x8fY\x12\x18\n\x13MT_EMC_COOLANT_STAT\x10\xebY\x12\x13\n\x0eMT_EMC_LUBE_ON\x10\xf0Y\x12\x14\n\x0fMT_EMC_LUBE_OFF\x10\xf1Y\x12\x15\n\x10MT_EMC_LUBE_STAT\x10\xcfZ\x12\x13\n\x0eMT_EMC_IO_INIT\x10\xd1Z\x12\x13\n\x0eMT_EMC_IO_HALT\x10\xd2Z\x12\x14\n\x0fMT_EMC_IO_ABORT\x10\xd3Z\x12\x1d\n\x18MT_EMC_IO_SET_CYCLE_TIME\x10\xd4Z\x12\x13\n\x0eMT_EMC_IO_STAT\x10\xb3[\x12\x10\n\x0bMT_EMC_INIT\x10\xfd\\\x12\x10\n\x0bMT_EMC_HALT\x10\xfe\\\x12\x11\n\x0cMT_EMC_ABORT\x10\xff\\\x12\x10\n\x0bMT_EMC_STAT\x10\xdf]\x12\x1b\n\x16MT_EMCSTAT_FULL_UPDATE\x10\xd4\x61\x12\"\n\x1dMT_EMCSTAT_INCREMENTAL_UPDATE\x10\xd5\x61\x12\x15\n\x10MT_EMC_NML_ERROR\x10\xde\x61\x12\x14\n\x0fMT_EMC_NML_TEXT\x10\xdf\x61\x12\x17\n\x12MT_EMC_NML_DISPLAY\x10\xe0\x61\x12\x17\n\x12MT_EMCCMD_EXECUTED\x10\xe8\x61\x12\x18\n\x13MT_EMCCMD_COMPLETED\x10\xe9\x61\x12\x1c\n\x17MT_LAUNCHER_FULL_UPDATE\x10\xb8\x62\x12#\n\x1eMT_LAUNCHER_INCREMENTAL_UPDATE\x10\xb9\x62\x12\x16\n\x11MT_LAUNCHER_ERROR\x10\xba\x62\x12\x16\n\x11MT_LAUNCHER_START\x10\xc2\x62\x12\x1a\n\x15MT_LAUNCHER_TERMINATE\x10\xc3\x62\x12\x15\n\x10MT_LAUNCHER_KILL\x10\xc4\x62\x12\x1c\n\x17MT_LAUNCHER_WRITE_STDIN\x10\xc5\x62\x12\x15\n\x10MT_LAUNCHER_CALL\x10\xc6\x62\x12\x19\n\x14MT_LAUNCHER_SHUTDOWN\x10\xc7\x62\x12\x14\n\x0fMT_LAUNCHER_SET\x10\xc8\x62*\xb7\x01\n\x0bOriginIndex\x12\x12\n\x0eORIGIN_UNKNOWN\x10\x00\x12\x0e\n\nORIGIN_G54\x10\x01\x12\x0e\n\nORIGIN_G55\x10\x02\x12\x0e\n\nORIGIN_G56\x10\x03\x12\x0e\n\nORIGIN_G57\x10\x04\x12\x0e\n\nORIGIN_G58\x10\x05\x12\x0e\n\nORIGIN_G59\x10\x06\x12\x10\n\x0cORIGIN_G59_1\x10\x07\x12\x10\n\x0cORIGIN_G59_2\x10\x08\x12\x10\n\x0cORIGIN_G59_3\x10\t*P\n\x11TermConditionType\x12\x1c\n\x18_EMC_TRAJ_TERM_COND_STOP\x10\x01\x12\x1d\n\x19_EMC_TRAJ_TERM_COND_BLEND\x10\x02*W\n\x0e\x43\x61nonDirection\x12\x12\n\x0e_CANON_STOPPED\x10\x01\x12\x14\n\x10_CANON_CLOCKWISE\x10\x02\x12\x1b\n\x17_CANON_COUNTERCLOCKWISE\x10\x03*2\n\tInputType\x12\x11\n\r_ANALOG_INPUT\x10\x00\x12\x12\n\x0e_DIGITAL_INPUT\x10\x01*F\n\x08WaitType\x12\r\n\tIMMEDIATE\x10\x00\x12\x08\n\x04RISE\x10\x01\x12\x08\n\x04\x46\x41LL\x10\x02\x12\x0b\n\x07\x42\x45_HIGH\x10\x03\x12\n\n\x06\x42\x45_LOW\x10\x04*\xaa\x01\n\x14InterpreterStateType\x12\x0f\n\x0bINTERP_IDLE\x10\x01\x12\x12\n\x0eINTERP_RUNNING\x10\x02\x12\x14\n\x10INTERP_SYNC_WAIT\x10\x03\x12\x11\n\rINTERP_PAUSED\x10\x04\x12\x15\n\x11INTERP_QUEUE_WAIT\x10\x05\x12\x15\n\x11INTERP_ABORT_WAIT\x10\x06\x12\x16\n\x12INTERP_STATE_UNSET\x10\x63')
  ,
  dependencies=[machinetalk_dot_protobuf_dot_nanopb__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_VALUETYPE = _descriptor.EnumDescriptor(
  name='ValueType',
  full_name='machinetalk.ValueType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HAL_BIT', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HAL_FLOAT', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HAL_S32', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HAL_U32', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HAL_S64', index=4, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HAL_U64', index=5, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRING', index=6, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BYTES', index=7, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INT32', index=8, number=20,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UINT32', index=9, number=30,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INT64', index=10, number=40,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UINT64', index=11, number=50,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOUBLE', index=12, number=60,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOOL', index=13, number=80,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CARTESIAN', index=14, number=100,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEGACY_CARTESIAN', index=15, number=110,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POSE', index=16, number=120,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEGACY_POSE', index=17, number=130,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=85,
  serialized_end=332,
)
_sym_db.RegisterEnumDescriptor(_VALUETYPE)

ValueType = enum_type_wrapper.EnumTypeWrapper(_VALUETYPE)
_HALPINDIRECTION = _descriptor.EnumDescriptor(
  name='HalPinDirection',
  full_name='machinetalk.HalPinDirection',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HAL_IN', index=0, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HAL_OUT', index=1, number=32,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HAL_IO', index=2, number=48,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=334,
  serialized_end=388,
)
_sym_db.RegisterEnumDescriptor(_HALPINDIRECTION)

HalPinDirection = enum_type_wrapper.EnumTypeWrapper(_HALPINDIRECTION)
_HALPARAMDIRECTION = _descriptor.EnumDescriptor(
  name='HalParamDirection',
  full_name='machinetalk.HalParamDirection',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HAL_RO', index=0, number=64,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HAL_RW', index=1, number=192,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=390,
  serialized_end=434,
)
_sym_db.RegisterEnumDescriptor(_HALPARAMDIRECTION)

HalParamDirection = enum_type_wrapper.EnumTypeWrapper(_HALPARAMDIRECTION)
_HALFUNCTTYPE = _descriptor.EnumDescriptor(
  name='HalFunctType',
  full_name='machinetalk.HalFunctType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FS_LEGACY_THREADFUNC', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FS_XTHREADFUNC', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FS_USERLAND', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=436,
  serialized_end=513,
)
_sym_db.RegisterEnumDescriptor(_HALFUNCTTYPE)

HalFunctType = enum_type_wrapper.EnumTypeWrapper(_HALFUNCTTYPE)
_OBJECTTYPE = _descriptor.EnumDescriptor(
  name='ObjectType',
  full_name='machinetalk.ObjectType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HAL_OBJECT_INVALID', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HAL_PIN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HAL_SIGNAL', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HAL_PARAM', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HAL_THREAD', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HAL_FUNCT', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HAL_COMPONENT', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HAL_VTABLE', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HAL_INST', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HAL_RING', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HAL_GROUP', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HAL_MEMBER', index=11, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HAL_PLUG', index=12, number=12,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=516,
  serialized_end=735,
)
_sym_db.RegisterEnumDescriptor(_OBJECTTYPE)

ObjectType = enum_type_wrapper.EnumTypeWrapper(_OBJECTTYPE)
_MSGIDTYPE = _descriptor.EnumDescriptor(
  name='msgidType',
  full_name='machinetalk.msgidType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MSGID_MAX', index=0, number=4000,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MSGID_ROUTE_DELIMITER', index=1, number=4001,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MSGID_ERROR_MSG', index=2, number=4002,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MSGID_BLOB', index=3, number=4003,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MSGID_STRING', index=4, number=4004,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MSGID_HOP', index=5, number=4005,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=738,
  serialized_end=867,
)
_sym_db.RegisterEnumDescriptor(_MSGIDTYPE)

msgidType = enum_type_wrapper.EnumTypeWrapper(_MSGIDTYPE)
_SOCKETTYPE = _descriptor.EnumDescriptor(
  name='socketType',
  full_name='machinetalk.socketType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ST_ZMQ_PAIR', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_ZMQ_PUB', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_ZMQ_SUB', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_ZMQ_REQ', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_ZMQ_REP', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_ZMQ_DEALER', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_ZMQ_ROUTER', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_ZMQ_PULL', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_ZMQ_PUSH', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_ZMQ_XPUB', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_ZMQ_XSUB', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_ZMQ_STREAM', index=11, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_ZMQ_INVALID', index=12, number=15,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=870,
  serialized_end=1108,
)
_sym_db.RegisterEnumDescriptor(_SOCKETTYPE)

socketType = enum_type_wrapper.EnumTypeWrapper(_SOCKETTYPE)
_SECURITYMECHANISM = _descriptor.EnumDescriptor(
  name='securityMechanism',
  full_name='machinetalk.securityMechanism',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SM_ZMQ_NONE', index=0, number=-1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SM_ZMQ_NULL', index=1, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SM_ZMQ_PLAIN', index=2, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SM_ZMQ_CURVE', index=3, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1110,
  serialized_end=1208,
)
_sym_db.RegisterEnumDescriptor(_SECURITYMECHANISM)

securityMechanism = enum_type_wrapper.EnumTypeWrapper(_SECURITYMECHANISM)
_RCS_STATUS = _descriptor.EnumDescriptor(
  name='RCS_STATUS',
  full_name='machinetalk.RCS_STATUS',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNINITIALIZED_STATUS', index=0, number=-1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RCS_DONE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RCS_EXEC', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RCS_ERROR', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RCS_RECEIVED', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1210,
  serialized_end=1318,
)
_sym_db.RegisterEnumDescriptor(_RCS_STATUS)

RCS_STATUS = enum_type_wrapper.EnumTypeWrapper(_RCS_STATUS)
_MSGORIGIN = _descriptor.EnumDescriptor(
  name='MsgOrigin',
  full_name='machinetalk.MsgOrigin',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MSG_KERNEL', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MSG_RTUSER', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MSG_ULAPI', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1320,
  serialized_end=1378,
)
_sym_db.RegisterEnumDescriptor(_MSGORIGIN)

MsgOrigin = enum_type_wrapper.EnumTypeWrapper(_MSGORIGIN)
_MSGLEVEL = _descriptor.EnumDescriptor(
  name='MsgLevel',
  full_name='machinetalk.MsgLevel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RTAPI_MSG_NONE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RTAPI_MSG_ERR', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RTAPI_MSG_WARN', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RTAPI_MSG_INFO', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RTAPI_MSG_DBG', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RTAPI_MSG_ALL', index=5, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1380,
  serialized_end=1507,
)
_sym_db.RegisterEnumDescriptor(_MSGLEVEL)

MsgLevel = enum_type_wrapper.EnumTypeWrapper(_MSGLEVEL)
_ORIGINDETAIL = _descriptor.EnumDescriptor(
  name='OriginDetail',
  full_name='machinetalk.OriginDetail',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNIX_SIGNAL', index=0, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INSTANCE_SHUTDOWN', index=1, number=20,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ZMQ_SOCKET', index=2, number=70,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NML_LAYER', index=3, number=80,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RCS_LAYER', index=4, number=90,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CMS_LAYER', index=5, number=100,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IP_LAYER', index=6, number=110,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TCP_LAYER', index=7, number=120,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PGM_LAYER', index=8, number=130,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1510,
  serialized_end=1670,
)
_sym_db.RegisterEnumDescriptor(_ORIGINDETAIL)

OriginDetail = enum_type_wrapper.EnumTypeWrapper(_ORIGINDETAIL)
_ORIGINTYPE = _descriptor.EnumDescriptor(
  name='OriginType',
  full_name='machinetalk.OriginType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PROCESS', index=0, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='USER_THREAD', index=1, number=20,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RT_THREAD', index=2, number=30,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMPONENT', index=3, number=40,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='THREAD_FUNCTION', index=4, number=50,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMPONENT_INIT', index=5, number=60,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMPONENT_EXIT', index=6, number=70,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GROUP', index=7, number=80,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PIN', index=8, number=90,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SIGNAL', index=9, number=100,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1673,
  serialized_end=1838,
)
_sym_db.RegisterEnumDescriptor(_ORIGINTYPE)

OriginType = enum_type_wrapper.EnumTypeWrapper(_ORIGINTYPE)
_SEVERITY = _descriptor.EnumDescriptor(
  name='Severity',
  full_name='machinetalk.Severity',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='S_INFORMATIONAL', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='S_WARNING', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='S_FAIL', index=2, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1840,
  serialized_end=1898,
)
_sym_db.RegisterEnumDescriptor(_SEVERITY)

Severity = enum_type_wrapper.EnumTypeWrapper(_SEVERITY)
_STATUSTYPE = _descriptor.EnumDescriptor(
  name='StatusType',
  full_name='machinetalk.StatusType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ENQUEUED', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROCESSING', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMPLETE', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=3, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1900,
  serialized_end=1968,
)
_sym_db.RegisterEnumDescriptor(_STATUSTYPE)

StatusType = enum_type_wrapper.EnumTypeWrapper(_STATUSTYPE)
_REPLYTYPE = _descriptor.EnumDescriptor(
  name='ReplyType',
  full_name='machinetalk.ReplyType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ON_RECEPTION', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ON_QUEUED', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ON_COMPLETION', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALL_STEPS', index=4, number=255,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1970,
  serialized_end=2059,
)
_sym_db.RegisterEnumDescriptor(_REPLYTYPE)

ReplyType = enum_type_wrapper.EnumTypeWrapper(_REPLYTYPE)
_SERVICETYPE = _descriptor.EnumDescriptor(
  name='ServiceType',
  full_name='machinetalk.ServiceType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ST_LOGGING', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_CONFIG', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_REDIS', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_HTTP', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_HTTPS', index=4, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_WEBSOCKET', index=5, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_WEBSOCKETS', index=6, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_RTAPI_COMMAND', index=7, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_STP_HALGROUP', index=8, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_STP_HALRCOMP', index=9, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_STP_INTERP', index=10, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_STP_TASK', index=11, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_HAL_RCOMMAND', index=12, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_TASK_COMMAND', index=13, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_INTERP_COMMAND', index=14, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_MESSAGEBUS_COMMAND', index=15, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_MESSAGEBUS_RESPONSE', index=16, number=17,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2062,
  serialized_end=2404,
)
_sym_db.RegisterEnumDescriptor(_SERVICETYPE)

ServiceType = enum_type_wrapper.EnumTypeWrapper(_SERVICETYPE)
_SERVICEAPI = _descriptor.EnumDescriptor(
  name='ServiceAPI',
  full_name='machinetalk.ServiceAPI',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SA_ZMQ_PROTOBUF', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SA_WS_JSON', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2406,
  serialized_end=2455,
)
_sym_db.RegisterEnumDescriptor(_SERVICEAPI)

ServiceAPI = enum_type_wrapper.EnumTypeWrapper(_SERVICEAPI)
_CONTAINERTYPE = _descriptor.EnumDescriptor(
  name='ContainerType',
  full_name='machinetalk.ContainerType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MT_RTMESSAGE', index=0, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_MOTCMD', index=1, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_MOTSTATUS', index=2, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_LEGACY_MOTCMD', index=3, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_LEGACY_MOTSTATUS', index=4, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_WOU', index=5, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_HALUPDATE', index=6, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_RTAPI_MESSAGE', index=7, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_LOG_MESSAGE', index=8, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_PREVIEW', index=9, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_PROGRESS', index=10, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_INTERP_STAT', index=11, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_SYSLOG', index=12, number=18,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_LEGACY_NML', index=13, number=19,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_LEGACY_MOTCONFIG', index=14, number=20,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_STP_UPDATE_FULL', index=15, number=26,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_STP_UPDATE', index=16, number=28,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_STP_NOGROUP', index=17, number=27,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_SHUTDOWN', index=18, number=45,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_CONFIRM_SHUTDOWN', index=19, number=50,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_RTMESSAGE0', index=20, number=30,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_RTMESSAGE1', index=21, number=31,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_RTMESSAGE2', index=22, number=32,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_RTMESSAGE3', index=23, number=33,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_RTMESSAGE4', index=24, number=34,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_ASCII', index=25, number=100,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_UNICODE', index=26, number=101,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_GCODE', index=27, number=102,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_PYTHON', index=28, number=103,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_PICKLE', index=29, number=104,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_TCL', index=30, number=105,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_XML', index=31, number=106,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_JSON', index=32, number=107,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_JPEG', index=33, number=108,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_PNG', index=34, number=109,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_TIFF', index=35, number=110,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_POSTSCRIPT', index=36, number=111,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_SVG', index=37, number=112,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_ZMQ_SUBSCRIBE', index=38, number=150,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_ZMQ_UNSUBSCRIBE', index=39, number=151,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_PING', index=40, number=210,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_PING_ACKNOWLEDGE', index=41, number=215,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_REJECT', index=42, number=220,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_DONE', index=43, number=240,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_SERVICE_REQUEST', index=44, number=250,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_SERVICE_ANNOUNCEMENT', index=45, number=251,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_SERVICE_PROBE', index=46, number=252,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_MESSAGEBUS_NO_DESTINATION', index=47, number=255,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_HALRCOMP_BIND', index=48, number=256,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_HALRCOMP_BIND_CONFIRM', index=49, number=257,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_HALRCOMP_BIND_REJECT', index=50, number=258,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_HALRCOMP_SET', index=51, number=259,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_HALRCOMP_SET_REJECT', index=52, number=260,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_HALRCOMP_ACK', index=53, number=263,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_HALRCOMMAND_SET', index=54, number=265,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_HALRCOMMAND_SET_REJECT', index=55, number=266,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_HALRCOMMAND_GET', index=56, number=267,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_HALRCOMMAND_GET_REJECT', index=57, number=268,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_HALRCOMMAND_CREATE', index=58, number=269,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_HALRCOMMAND_CREATE_REJECT', index=59, number=270,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_HALRCOMMAND_DELETE', index=60, number=271,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_HALRCOMMAND_DELETE_REJECT', index=61, number=272,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_HALRCOMMAND_ACK', index=62, number=273,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_HALRCOMMAND_ERROR', index=63, number=274,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_HALRCOMMAND_DESCRIBE', index=64, number=276,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_HALRCOMMAND_DESCRIPTION', index=65, number=277,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_HALRCOMP_FULL_UPDATE', index=66, number=288,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_HALRCOMP_INCREMENTAL_UPDATE', index=67, number=289,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_HALRCOMP_ERROR', index=68, number=290,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_HALGROUP_BIND', index=69, number=294,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_HALGROUP_BIND_CONFIRM', index=70, number=295,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_HALGROUP_BIND_REJECT', index=71, number=296,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_HALGROUP_FULL_UPDATE', index=72, number=297,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_HALGROUP_INCREMENTAL_UPDATE', index=73, number=298,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_HALGROUP_ERROR', index=74, number=299,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_RTAPI_APP_EXIT', index=75, number=300,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_RTAPI_APP_PING', index=76, number=301,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_RTAPI_APP_LOADRT', index=77, number=302,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_RTAPI_APP_LOG', index=78, number=303,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_RTAPI_APP_UNLOADRT', index=79, number=305,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_RTAPI_APP_NEWINST', index=80, number=306,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_RTAPI_APP_NEWTHREAD', index=81, number=307,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_RTAPI_APP_DELTHREAD', index=82, number=308,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_RTAPI_APP_CALLFUNC', index=83, number=309,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_RTAPI_APP_REPLY', index=84, number=310,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_RTAPI_APP_DELINST', index=85, number=311,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_LIST_APPLICATIONS', index=86, number=350,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_DESCRIBE_APPLICATION', index=87, number=351,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_RETRIEVE_APPLICATION', index=88, number=352,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_APPLICATION_DETAIL', index=89, number=353,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_ERROR', index=90, number=360,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_FULL_UPDATE', index=91, number=370,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_INCREMENTAL_UPDATE', index=92, number=371,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_TASK_REPLY', index=93, number=400,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_TICKET_UPDATE', index=94, number=401,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_CREDIT_UPDATE', index=95, number=450,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_LOWER', index=96, number=1000,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_UPPER', index=97, number=1100,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_ABORT', index=98, number=1001,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_AXIS_ABORT', index=99, number=1002,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_ENABLE', index=100, number=1003,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_DISABLE', index=101, number=1004,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_ENABLE_AMPLIFIER', index=102, number=1005,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_DISABLE_AMPLIFIER', index=103, number=1006,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_ENABLE_WATCHDOG', index=104, number=1007,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_DISABLE_WATCHDOG', index=105, number=1008,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_ACTIVATE_JOINT', index=106, number=1009,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_DEACTIVATE_JOINT', index=107, number=1010,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_PAUSE', index=108, number=1011,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_RESUME', index=109, number=1012,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_STEP', index=110, number=1013,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_FREE', index=111, number=1014,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_COORD', index=112, number=1015,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_TELEOP', index=113, number=1016,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_SPINDLE_SCALE', index=114, number=1017,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_SS_ENABLE', index=115, number=1018,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_FEED_SCALE', index=116, number=1019,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_FS_ENABLE', index=117, number=1020,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_FH_ENABLE', index=118, number=1021,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_AF_ENABLE', index=119, number=1022,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_OVERRIDE_LIMITS', index=120, number=1023,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_HOME', index=121, number=1024,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_UNHOME', index=122, number=1025,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_JOG_CONT', index=123, number=1026,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_JOG_INCR', index=124, number=1027,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_JOG_ABS', index=125, number=1028,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_SET_LINE', index=126, number=1029,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_SET_CIRCLE', index=127, number=1030,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_SET_TELEOP_VECTOR', index=128, number=1031,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_CLEAR_PROBE_FLAGS', index=129, number=1032,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_PROBE', index=130, number=1033,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_RIGID_TAP', index=131, number=1034,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_SET_POSITION_LIMITS', index=132, number=1035,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_SET_BACKLASH', index=133, number=1036,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_SET_MIN_FERROR', index=134, number=1037,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_SET_MAX_FERROR', index=135, number=1038,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_SET_VEL', index=136, number=1039,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_SET_VEL_LIMIT', index=137, number=1040,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_SET_JOINT_VEL_LIMIT', index=138, number=1041,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_SET_JOINT_ACC_LIMIT', index=139, number=1042,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_SET_ACC', index=140, number=1043,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_SET_TERM_COND', index=141, number=1044,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_SET_NUM_AXES', index=142, number=1045,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_SET_WORLD_HOME', index=143, number=1046,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_SET_HOMING_PARAMS', index=144, number=1047,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_SET_DEBUG', index=145, number=1048,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_SET_DOUT', index=146, number=1049,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_SET_AOUT', index=147, number=1050,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_SET_SPINDLESYNC', index=148, number=1051,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_SPINDLE_ON', index=149, number=1052,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_SPINDLE_OFF', index=150, number=1053,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_SPINDLE_INCREASE', index=151, number=1054,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_SPINDLE_DECREASE', index=152, number=1055,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_SPINDLE_BRAKE_ENGAGE', index=153, number=1056,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_SPINDLE_BRAKE_RELEASE', index=154, number=1057,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_SET_MOTOR_OFFSET', index=155, number=1058,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_SET_JOINT_COMP', index=156, number=1059,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_SET_OFFSET', index=157, number=1060,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_COMMAND_OK', index=158, number=1061,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_COMMAND_UNKNOWN_COMMAND', index=159, number=1062,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_COMMAND_INVALID_COMMAND', index=160, number=1063,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_COMMAND_INVALID_PARAMS', index=161, number=1064,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_COMMAND_BAD_EXEC', index=162, number=1065,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_MOTION_DISABLED', index=163, number=1066,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_MOTION_FREE', index=164, number=1067,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_MOTION_TELEOP', index=165, number=1068,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_MOTION_COORD', index=166, number=1069,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_JOINT_FLAG', index=167, number=1070,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCMOT_MOTION_FLAG', index=168, number=1071,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_PRU_FIRMWARE', index=169, number=2048,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_MESA_5I20_FIRMWARE', index=170, number=3000,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_BLOB', index=171, number=4000,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_TEST1', index=172, number=5001,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_TEST2', index=173, number=5002,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_TEST3', index=174, number=5003,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_NML_LOWER', index=175, number=10000,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_NML_UPPER', index=176, number=13000,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_OPERATOR_ERROR', index=177, number=10011,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_OPERATOR_TEXT', index=178, number=10012,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_OPERATOR_DISPLAY', index=179, number=10013,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_NULL', index=180, number=10021,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_SET_DEBUG', index=181, number=10022,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_SYSTEM_CMD', index=182, number=10030,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_AXIS_SET_AXIS', index=183, number=10101,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_AXIS_SET_UNITS', index=184, number=10102,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_AXIS_SET_MIN_POSITION_LIMIT', index=185, number=10107,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_AXIS_SET_MAX_POSITION_LIMIT', index=186, number=10108,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TOOL_START_CHANGE', index=187, number=1110,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_EXEC_PLUGIN_CALL', index=188, number=1112,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_IO_PLUGIN_CALL', index=189, number=1113,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_AXIS_SET_FERROR', index=190, number=10111,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_AXIS_SET_HOMING_PARAMS', index=191, number=10112,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_AXIS_SET_MIN_FERROR', index=192, number=10115,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_AXIS_SET_MAX_VELOCITY', index=193, number=10116,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_AXIS_INIT', index=194, number=10118,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_AXIS_HALT', index=195, number=10119,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_AXIS_ABORT', index=196, number=10120,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_AXIS_ENABLE', index=197, number=10121,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_AXIS_DISABLE', index=198, number=10122,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_AXIS_HOME', index=199, number=10123,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_AXIS_UNHOME', index=200, number=10135,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_AXIS_JOG', index=201, number=10124,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_AXIS_INCR_JOG', index=202, number=10125,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_AXIS_ABS_JOG', index=203, number=10126,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_AXIS_ACTIVATE', index=204, number=10127,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_AXIS_DEACTIVATE', index=205, number=10128,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_AXIS_OVERRIDE_LIMITS', index=206, number=10129,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_AXIS_LOAD_COMP', index=207, number=10131,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_AXIS_SET_BACKLASH', index=208, number=10134,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_AXIS_STAT', index=209, number=10199,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_SET_AXES', index=210, number=10201,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_SET_UNITS', index=211, number=10202,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_SET_CYCLE_TIME', index=212, number=10203,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_SET_MODE', index=213, number=10204,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_SET_VELOCITY', index=214, number=10205,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_SET_ACCELERATION', index=215, number=10206,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_SET_MAX_VELOCITY', index=216, number=10207,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_SET_MAX_ACCELERATION', index=217, number=10208,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_SET_SCALE', index=218, number=10209,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_SET_MOTION_ID', index=219, number=10210,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_INIT', index=220, number=10211,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_HALT', index=221, number=10212,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_ENABLE', index=222, number=10213,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_DISABLE', index=223, number=10214,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_ABORT', index=224, number=10215,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_PAUSE', index=225, number=10216,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_STEP', index=226, number=10217,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_RESUME', index=227, number=10218,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_DELAY', index=228, number=10219,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_LINEAR_MOVE', index=229, number=10220,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_CIRCULAR_MOVE', index=230, number=10221,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_SET_TERM_COND', index=231, number=10222,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_SET_OFFSET', index=232, number=10223,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_SET_G5X', index=233, number=10224,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_SET_HOME', index=234, number=10225,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_SET_ROTATION', index=235, number=10226,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_SET_G92', index=236, number=10227,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_CLEAR_PROBE_TRIPPED_FLAG', index=237, number=10228,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_PROBE', index=238, number=10229,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_SET_TELEOP_ENABLE', index=239, number=10230,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_SET_TELEOP_VECTOR', index=240, number=10231,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_SET_SPINDLESYNC', index=241, number=10232,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_SET_SPINDLE_SCALE', index=242, number=10233,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_SET_FO_ENABLE', index=243, number=10234,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_SET_SO_ENABLE', index=244, number=10235,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_SET_FH_ENABLE', index=245, number=10236,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_RIGID_TAP', index=246, number=10237,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_SET_RAPID_SCALE', index=247, number=10238,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TRAJ_STAT', index=248, number=10299,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_MOTION_INIT', index=249, number=10301,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_MOTION_HALT', index=250, number=10302,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_MOTION_ABORT', index=251, number=10303,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_MOTION_SET_AOUT', index=252, number=10304,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_MOTION_SET_DOUT', index=253, number=10305,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_MOTION_ADAPTIVE', index=254, number=10306,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_SPINDLE_ORIENT', index=255, number=10317,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_SPINDLE_WAIT_ORIENT_COMPLETE', index=256, number=10318,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_MOTION_STAT', index=257, number=10399,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TASK_INIT', index=258, number=10501,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TASK_HALT', index=259, number=10502,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TASK_ABORT', index=260, number=10503,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TASK_SET_MODE', index=261, number=10504,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TASK_SET_STATE', index=262, number=10505,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TASK_PLAN_OPEN', index=263, number=10506,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TASK_PLAN_RUN', index=264, number=10507,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TASK_PLAN_READ', index=265, number=10508,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TASK_PLAN_EXECUTE', index=266, number=10509,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TASK_PLAN_PAUSE', index=267, number=10510,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TASK_PLAN_STEP', index=268, number=10511,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TASK_PLAN_RESUME', index=269, number=10512,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TASK_PLAN_END', index=270, number=10513,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TASK_PLAN_CLOSE', index=271, number=10514,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TASK_PLAN_INIT', index=272, number=10515,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TASK_PLAN_SYNCH', index=273, number=10516,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TASK_PLAN_SET_OPTIONAL_STOP', index=274, number=10517,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TASK_PLAN_SET_BLOCK_DELETE', index=275, number=10518,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TASK_PLAN_OPTIONAL_STOP', index=276, number=10519,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TASK_PLAN_RESET', index=277, number=10520,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TASK_PLAN_REPLY', index=278, number=10530,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TASK_STAT', index=279, number=10599,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TOOL_INIT', index=280, number=11101,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TOOL_HALT', index=281, number=11102,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TOOL_ABORT', index=282, number=11103,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TOOL_PREPARE', index=283, number=11104,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TOOL_LOAD', index=284, number=11105,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TOOL_UNLOAD', index=285, number=11106,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TOOL_LOAD_TOOL_TABLE', index=286, number=11107,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TOOL_SET_OFFSET', index=287, number=11108,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TOOL_SET_NUMBER', index=288, number=11109,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TOOL_UPDATE_TOOL_TABLE', index=289, number=11110,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_TOOL_STAT', index=290, number=11199,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_AUX_ESTOP_ON', index=291, number=11206,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_AUX_ESTOP_OFF', index=292, number=11207,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_AUX_ESTOP_RESET', index=293, number=11208,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_AUX_INPUT_WAIT', index=294, number=11209,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_AUX_STAT', index=295, number=11299,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_SPINDLE_ON', index=296, number=11304,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_SPINDLE_OFF', index=297, number=11305,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_SPINDLE_INCREASE', index=298, number=11309,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_SPINDLE_DECREASE', index=299, number=11310,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_SPINDLE_CONSTANT', index=300, number=11311,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_SPINDLE_BRAKE_RELEASE', index=301, number=11312,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_SPINDLE_BRAKE_ENGAGE', index=302, number=11313,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_SPINDLE_SPEED', index=303, number=11316,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_SPINDLE_STAT', index=304, number=11399,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_COOLANT_MIST_ON', index=305, number=11404,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_COOLANT_MIST_OFF', index=306, number=11405,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_COOLANT_FLOOD_ON', index=307, number=11406,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_COOLANT_FLOOD_OFF', index=308, number=11407,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_COOLANT_STAT', index=309, number=11499,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_LUBE_ON', index=310, number=11504,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_LUBE_OFF', index=311, number=11505,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_LUBE_STAT', index=312, number=11599,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_IO_INIT', index=313, number=11601,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_IO_HALT', index=314, number=11602,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_IO_ABORT', index=315, number=11603,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_IO_SET_CYCLE_TIME', index=316, number=11604,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_IO_STAT', index=317, number=11699,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_INIT', index=318, number=11901,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_HALT', index=319, number=11902,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_ABORT', index=320, number=11903,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_STAT', index=321, number=11999,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCSTAT_FULL_UPDATE', index=322, number=12500,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCSTAT_INCREMENTAL_UPDATE', index=323, number=12501,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_NML_ERROR', index=324, number=12510,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_NML_TEXT', index=325, number=12511,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMC_NML_DISPLAY', index=326, number=12512,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCCMD_EXECUTED', index=327, number=12520,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_EMCCMD_COMPLETED', index=328, number=12521,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_LAUNCHER_FULL_UPDATE', index=329, number=12600,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_LAUNCHER_INCREMENTAL_UPDATE', index=330, number=12601,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_LAUNCHER_ERROR', index=331, number=12602,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_LAUNCHER_START', index=332, number=12610,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_LAUNCHER_TERMINATE', index=333, number=12611,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_LAUNCHER_KILL', index=334, number=12612,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_LAUNCHER_WRITE_STDIN', index=335, number=12613,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_LAUNCHER_CALL', index=336, number=12614,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_LAUNCHER_SHUTDOWN', index=337, number=12615,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MT_LAUNCHER_SET', index=338, number=12616,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2458,
  serialized_end=11449,
)
_sym_db.RegisterEnumDescriptor(_CONTAINERTYPE)

ContainerType = enum_type_wrapper.EnumTypeWrapper(_CONTAINERTYPE)
_ORIGININDEX = _descriptor.EnumDescriptor(
  name='OriginIndex',
  full_name='machinetalk.OriginIndex',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ORIGIN_UNKNOWN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORIGIN_G54', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORIGIN_G55', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORIGIN_G56', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORIGIN_G57', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORIGIN_G58', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORIGIN_G59', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORIGIN_G59_1', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORIGIN_G59_2', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORIGIN_G59_3', index=9, number=9,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=11452,
  serialized_end=11635,
)
_sym_db.RegisterEnumDescriptor(_ORIGININDEX)

OriginIndex = enum_type_wrapper.EnumTypeWrapper(_ORIGININDEX)
_TERMCONDITIONTYPE = _descriptor.EnumDescriptor(
  name='TermConditionType',
  full_name='machinetalk.TermConditionType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='_EMC_TRAJ_TERM_COND_STOP', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='_EMC_TRAJ_TERM_COND_BLEND', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=11637,
  serialized_end=11717,
)
_sym_db.RegisterEnumDescriptor(_TERMCONDITIONTYPE)

TermConditionType = enum_type_wrapper.EnumTypeWrapper(_TERMCONDITIONTYPE)
_CANONDIRECTION = _descriptor.EnumDescriptor(
  name='CanonDirection',
  full_name='machinetalk.CanonDirection',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='_CANON_STOPPED', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='_CANON_CLOCKWISE', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='_CANON_COUNTERCLOCKWISE', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=11719,
  serialized_end=11806,
)
_sym_db.RegisterEnumDescriptor(_CANONDIRECTION)

CanonDirection = enum_type_wrapper.EnumTypeWrapper(_CANONDIRECTION)
_INPUTTYPE = _descriptor.EnumDescriptor(
  name='InputType',
  full_name='machinetalk.InputType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='_ANALOG_INPUT', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='_DIGITAL_INPUT', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=11808,
  serialized_end=11858,
)
_sym_db.RegisterEnumDescriptor(_INPUTTYPE)

InputType = enum_type_wrapper.EnumTypeWrapper(_INPUTTYPE)
_WAITTYPE = _descriptor.EnumDescriptor(
  name='WaitType',
  full_name='machinetalk.WaitType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IMMEDIATE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RISE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FALL', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BE_HIGH', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BE_LOW', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=11860,
  serialized_end=11930,
)
_sym_db.RegisterEnumDescriptor(_WAITTYPE)

WaitType = enum_type_wrapper.EnumTypeWrapper(_WAITTYPE)
_INTERPRETERSTATETYPE = _descriptor.EnumDescriptor(
  name='InterpreterStateType',
  full_name='machinetalk.InterpreterStateType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INTERP_IDLE', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERP_RUNNING', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERP_SYNC_WAIT', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERP_PAUSED', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERP_QUEUE_WAIT', index=4, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERP_ABORT_WAIT', index=5, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERP_STATE_UNSET', index=6, number=99,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=11933,
  serialized_end=12103,
)
_sym_db.RegisterEnumDescriptor(_INTERPRETERSTATETYPE)

InterpreterStateType = enum_type_wrapper.EnumTypeWrapper(_INTERPRETERSTATETYPE)
HAL_BIT = 1
HAL_FLOAT = 2
HAL_S32 = 3
HAL_U32 = 4
HAL_S64 = 5
HAL_U64 = 6
STRING = 7
BYTES = 8
INT32 = 20
UINT32 = 30
INT64 = 40
UINT64 = 50
DOUBLE = 60
BOOL = 80
CARTESIAN = 100
LEGACY_CARTESIAN = 110
POSE = 120
LEGACY_POSE = 130
HAL_IN = 16
HAL_OUT = 32
HAL_IO = 48
HAL_RO = 64
HAL_RW = 192
FS_LEGACY_THREADFUNC = 0
FS_XTHREADFUNC = 1
FS_USERLAND = 2
HAL_OBJECT_INVALID = 0
HAL_PIN = 1
HAL_SIGNAL = 2
HAL_PARAM = 3
HAL_THREAD = 4
HAL_FUNCT = 5
HAL_COMPONENT = 6
HAL_VTABLE = 7
HAL_INST = 8
HAL_RING = 9
HAL_GROUP = 10
HAL_MEMBER = 11
HAL_PLUG = 12
MSGID_MAX = 4000
MSGID_ROUTE_DELIMITER = 4001
MSGID_ERROR_MSG = 4002
MSGID_BLOB = 4003
MSGID_STRING = 4004
MSGID_HOP = 4005
ST_ZMQ_PAIR = 0
ST_ZMQ_PUB = 1
ST_ZMQ_SUB = 2
ST_ZMQ_REQ = 3
ST_ZMQ_REP = 4
ST_ZMQ_DEALER = 5
ST_ZMQ_ROUTER = 6
ST_ZMQ_PULL = 7
ST_ZMQ_PUSH = 8
ST_ZMQ_XPUB = 9
ST_ZMQ_XSUB = 10
ST_ZMQ_STREAM = 11
ST_ZMQ_INVALID = 15
SM_ZMQ_NONE = -1
SM_ZMQ_NULL = 0
SM_ZMQ_PLAIN = 1
SM_ZMQ_CURVE = 2
UNINITIALIZED_STATUS = -1
RCS_DONE = 1
RCS_EXEC = 2
RCS_ERROR = 3
RCS_RECEIVED = 4
MSG_KERNEL = 0
MSG_RTUSER = 1
MSG_ULAPI = 2
RTAPI_MSG_NONE = 0
RTAPI_MSG_ERR = 1
RTAPI_MSG_WARN = 2
RTAPI_MSG_INFO = 3
RTAPI_MSG_DBG = 4
RTAPI_MSG_ALL = 5
UNIX_SIGNAL = 10
INSTANCE_SHUTDOWN = 20
ZMQ_SOCKET = 70
NML_LAYER = 80
RCS_LAYER = 90
CMS_LAYER = 100
IP_LAYER = 110
TCP_LAYER = 120
PGM_LAYER = 130
PROCESS = 10
USER_THREAD = 20
RT_THREAD = 30
COMPONENT = 40
THREAD_FUNCTION = 50
COMPONENT_INIT = 60
COMPONENT_EXIT = 70
GROUP = 80
PIN = 90
SIGNAL = 100
S_INFORMATIONAL = 1
S_WARNING = 2
S_FAIL = 4
ENQUEUED = 1
PROCESSING = 2
COMPLETE = 3
FAILED = 4
NONE = 0
ON_RECEPTION = 1
ON_QUEUED = 2
ON_COMPLETION = 4
ALL_STEPS = 255
ST_LOGGING = 1
ST_CONFIG = 2
ST_REDIS = 3
ST_HTTP = 4
ST_HTTPS = 5
ST_WEBSOCKET = 6
ST_WEBSOCKETS = 7
ST_RTAPI_COMMAND = 8
ST_STP_HALGROUP = 9
ST_STP_HALRCOMP = 10
ST_STP_INTERP = 11
ST_STP_TASK = 12
ST_HAL_RCOMMAND = 13
ST_TASK_COMMAND = 14
ST_INTERP_COMMAND = 15
ST_MESSAGEBUS_COMMAND = 16
ST_MESSAGEBUS_RESPONSE = 17
SA_ZMQ_PROTOBUF = 1
SA_WS_JSON = 2
MT_RTMESSAGE = 2
MT_MOTCMD = 3
MT_MOTSTATUS = 4
MT_LEGACY_MOTCMD = 5
MT_LEGACY_MOTSTATUS = 6
MT_WOU = 7
MT_HALUPDATE = 8
MT_RTAPI_MESSAGE = 9
MT_LOG_MESSAGE = 10
MT_PREVIEW = 11
MT_PROGRESS = 12
MT_INTERP_STAT = 13
MT_SYSLOG = 18
MT_LEGACY_NML = 19
MT_LEGACY_MOTCONFIG = 20
MT_STP_UPDATE_FULL = 26
MT_STP_UPDATE = 28
MT_STP_NOGROUP = 27
MT_SHUTDOWN = 45
MT_CONFIRM_SHUTDOWN = 50
MT_RTMESSAGE0 = 30
MT_RTMESSAGE1 = 31
MT_RTMESSAGE2 = 32
MT_RTMESSAGE3 = 33
MT_RTMESSAGE4 = 34
MT_ASCII = 100
MT_UNICODE = 101
MT_GCODE = 102
MT_PYTHON = 103
MT_PICKLE = 104
MT_TCL = 105
MT_XML = 106
MT_JSON = 107
MT_JPEG = 108
MT_PNG = 109
MT_TIFF = 110
MT_POSTSCRIPT = 111
MT_SVG = 112
MT_ZMQ_SUBSCRIBE = 150
MT_ZMQ_UNSUBSCRIBE = 151
MT_PING = 210
MT_PING_ACKNOWLEDGE = 215
MT_REJECT = 220
MT_DONE = 240
MT_SERVICE_REQUEST = 250
MT_SERVICE_ANNOUNCEMENT = 251
MT_SERVICE_PROBE = 252
MT_MESSAGEBUS_NO_DESTINATION = 255
MT_HALRCOMP_BIND = 256
MT_HALRCOMP_BIND_CONFIRM = 257
MT_HALRCOMP_BIND_REJECT = 258
MT_HALRCOMP_SET = 259
MT_HALRCOMP_SET_REJECT = 260
MT_HALRCOMP_ACK = 263
MT_HALRCOMMAND_SET = 265
MT_HALRCOMMAND_SET_REJECT = 266
MT_HALRCOMMAND_GET = 267
MT_HALRCOMMAND_GET_REJECT = 268
MT_HALRCOMMAND_CREATE = 269
MT_HALRCOMMAND_CREATE_REJECT = 270
MT_HALRCOMMAND_DELETE = 271
MT_HALRCOMMAND_DELETE_REJECT = 272
MT_HALRCOMMAND_ACK = 273
MT_HALRCOMMAND_ERROR = 274
MT_HALRCOMMAND_DESCRIBE = 276
MT_HALRCOMMAND_DESCRIPTION = 277
MT_HALRCOMP_FULL_UPDATE = 288
MT_HALRCOMP_INCREMENTAL_UPDATE = 289
MT_HALRCOMP_ERROR = 290
MT_HALGROUP_BIND = 294
MT_HALGROUP_BIND_CONFIRM = 295
MT_HALGROUP_BIND_REJECT = 296
MT_HALGROUP_FULL_UPDATE = 297
MT_HALGROUP_INCREMENTAL_UPDATE = 298
MT_HALGROUP_ERROR = 299
MT_RTAPI_APP_EXIT = 300
MT_RTAPI_APP_PING = 301
MT_RTAPI_APP_LOADRT = 302
MT_RTAPI_APP_LOG = 303
MT_RTAPI_APP_UNLOADRT = 305
MT_RTAPI_APP_NEWINST = 306
MT_RTAPI_APP_NEWTHREAD = 307
MT_RTAPI_APP_DELTHREAD = 308
MT_RTAPI_APP_CALLFUNC = 309
MT_RTAPI_APP_REPLY = 310
MT_RTAPI_APP_DELINST = 311
MT_LIST_APPLICATIONS = 350
MT_DESCRIBE_APPLICATION = 351
MT_RETRIEVE_APPLICATION = 352
MT_APPLICATION_DETAIL = 353
MT_ERROR = 360
MT_FULL_UPDATE = 370
MT_INCREMENTAL_UPDATE = 371
MT_TASK_REPLY = 400
MT_TICKET_UPDATE = 401
MT_CREDIT_UPDATE = 450
MT_EMCMOT_LOWER = 1000
MT_EMCMOT_UPPER = 1100
MT_EMCMOT_ABORT = 1001
MT_EMCMOT_AXIS_ABORT = 1002
MT_EMCMOT_ENABLE = 1003
MT_EMCMOT_DISABLE = 1004
MT_EMCMOT_ENABLE_AMPLIFIER = 1005
MT_EMCMOT_DISABLE_AMPLIFIER = 1006
MT_EMCMOT_ENABLE_WATCHDOG = 1007
MT_EMCMOT_DISABLE_WATCHDOG = 1008
MT_EMCMOT_ACTIVATE_JOINT = 1009
MT_EMCMOT_DEACTIVATE_JOINT = 1010
MT_EMCMOT_PAUSE = 1011
MT_EMCMOT_RESUME = 1012
MT_EMCMOT_STEP = 1013
MT_EMCMOT_FREE = 1014
MT_EMCMOT_COORD = 1015
MT_EMCMOT_TELEOP = 1016
MT_EMCMOT_SPINDLE_SCALE = 1017
MT_EMCMOT_SS_ENABLE = 1018
MT_EMCMOT_FEED_SCALE = 1019
MT_EMCMOT_FS_ENABLE = 1020
MT_EMCMOT_FH_ENABLE = 1021
MT_EMCMOT_AF_ENABLE = 1022
MT_EMCMOT_OVERRIDE_LIMITS = 1023
MT_EMCMOT_HOME = 1024
MT_EMCMOT_UNHOME = 1025
MT_EMCMOT_JOG_CONT = 1026
MT_EMCMOT_JOG_INCR = 1027
MT_EMCMOT_JOG_ABS = 1028
MT_EMCMOT_SET_LINE = 1029
MT_EMCMOT_SET_CIRCLE = 1030
MT_EMCMOT_SET_TELEOP_VECTOR = 1031
MT_EMCMOT_CLEAR_PROBE_FLAGS = 1032
MT_EMCMOT_PROBE = 1033
MT_EMCMOT_RIGID_TAP = 1034
MT_EMCMOT_SET_POSITION_LIMITS = 1035
MT_EMCMOT_SET_BACKLASH = 1036
MT_EMCMOT_SET_MIN_FERROR = 1037
MT_EMCMOT_SET_MAX_FERROR = 1038
MT_EMCMOT_SET_VEL = 1039
MT_EMCMOT_SET_VEL_LIMIT = 1040
MT_EMCMOT_SET_JOINT_VEL_LIMIT = 1041
MT_EMCMOT_SET_JOINT_ACC_LIMIT = 1042
MT_EMCMOT_SET_ACC = 1043
MT_EMCMOT_SET_TERM_COND = 1044
MT_EMCMOT_SET_NUM_AXES = 1045
MT_EMCMOT_SET_WORLD_HOME = 1046
MT_EMCMOT_SET_HOMING_PARAMS = 1047
MT_EMCMOT_SET_DEBUG = 1048
MT_EMCMOT_SET_DOUT = 1049
MT_EMCMOT_SET_AOUT = 1050
MT_EMCMOT_SET_SPINDLESYNC = 1051
MT_EMCMOT_SPINDLE_ON = 1052
MT_EMCMOT_SPINDLE_OFF = 1053
MT_EMCMOT_SPINDLE_INCREASE = 1054
MT_EMCMOT_SPINDLE_DECREASE = 1055
MT_EMCMOT_SPINDLE_BRAKE_ENGAGE = 1056
MT_EMCMOT_SPINDLE_BRAKE_RELEASE = 1057
MT_EMCMOT_SET_MOTOR_OFFSET = 1058
MT_EMCMOT_SET_JOINT_COMP = 1059
MT_EMCMOT_SET_OFFSET = 1060
MT_EMCMOT_COMMAND_OK = 1061
MT_EMCMOT_COMMAND_UNKNOWN_COMMAND = 1062
MT_EMCMOT_COMMAND_INVALID_COMMAND = 1063
MT_EMCMOT_COMMAND_INVALID_PARAMS = 1064
MT_EMCMOT_COMMAND_BAD_EXEC = 1065
MT_EMCMOT_MOTION_DISABLED = 1066
MT_EMCMOT_MOTION_FREE = 1067
MT_EMCMOT_MOTION_TELEOP = 1068
MT_EMCMOT_MOTION_COORD = 1069
MT_EMCMOT_JOINT_FLAG = 1070
MT_EMCMOT_MOTION_FLAG = 1071
MT_PRU_FIRMWARE = 2048
MT_MESA_5I20_FIRMWARE = 3000
MT_BLOB = 4000
MT_TEST1 = 5001
MT_TEST2 = 5002
MT_TEST3 = 5003
MT_EMC_NML_LOWER = 10000
MT_EMC_NML_UPPER = 13000
MT_EMC_OPERATOR_ERROR = 10011
MT_EMC_OPERATOR_TEXT = 10012
MT_EMC_OPERATOR_DISPLAY = 10013
MT_EMC_NULL = 10021
MT_EMC_SET_DEBUG = 10022
MT_EMC_SYSTEM_CMD = 10030
MT_EMC_AXIS_SET_AXIS = 10101
MT_EMC_AXIS_SET_UNITS = 10102
MT_EMC_AXIS_SET_MIN_POSITION_LIMIT = 10107
MT_EMC_AXIS_SET_MAX_POSITION_LIMIT = 10108
MT_EMC_TOOL_START_CHANGE = 1110
MT_EMC_EXEC_PLUGIN_CALL = 1112
MT_EMC_IO_PLUGIN_CALL = 1113
MT_EMC_AXIS_SET_FERROR = 10111
MT_EMC_AXIS_SET_HOMING_PARAMS = 10112
MT_EMC_AXIS_SET_MIN_FERROR = 10115
MT_EMC_AXIS_SET_MAX_VELOCITY = 10116
MT_EMC_AXIS_INIT = 10118
MT_EMC_AXIS_HALT = 10119
MT_EMC_AXIS_ABORT = 10120
MT_EMC_AXIS_ENABLE = 10121
MT_EMC_AXIS_DISABLE = 10122
MT_EMC_AXIS_HOME = 10123
MT_EMC_AXIS_UNHOME = 10135
MT_EMC_AXIS_JOG = 10124
MT_EMC_AXIS_INCR_JOG = 10125
MT_EMC_AXIS_ABS_JOG = 10126
MT_EMC_AXIS_ACTIVATE = 10127
MT_EMC_AXIS_DEACTIVATE = 10128
MT_EMC_AXIS_OVERRIDE_LIMITS = 10129
MT_EMC_AXIS_LOAD_COMP = 10131
MT_EMC_AXIS_SET_BACKLASH = 10134
MT_EMC_AXIS_STAT = 10199
MT_EMC_TRAJ_SET_AXES = 10201
MT_EMC_TRAJ_SET_UNITS = 10202
MT_EMC_TRAJ_SET_CYCLE_TIME = 10203
MT_EMC_TRAJ_SET_MODE = 10204
MT_EMC_TRAJ_SET_VELOCITY = 10205
MT_EMC_TRAJ_SET_ACCELERATION = 10206
MT_EMC_TRAJ_SET_MAX_VELOCITY = 10207
MT_EMC_TRAJ_SET_MAX_ACCELERATION = 10208
MT_EMC_TRAJ_SET_SCALE = 10209
MT_EMC_TRAJ_SET_MOTION_ID = 10210
MT_EMC_TRAJ_INIT = 10211
MT_EMC_TRAJ_HALT = 10212
MT_EMC_TRAJ_ENABLE = 10213
MT_EMC_TRAJ_DISABLE = 10214
MT_EMC_TRAJ_ABORT = 10215
MT_EMC_TRAJ_PAUSE = 10216
MT_EMC_TRAJ_STEP = 10217
MT_EMC_TRAJ_RESUME = 10218
MT_EMC_TRAJ_DELAY = 10219
MT_EMC_TRAJ_LINEAR_MOVE = 10220
MT_EMC_TRAJ_CIRCULAR_MOVE = 10221
MT_EMC_TRAJ_SET_TERM_COND = 10222
MT_EMC_TRAJ_SET_OFFSET = 10223
MT_EMC_TRAJ_SET_G5X = 10224
MT_EMC_TRAJ_SET_HOME = 10225
MT_EMC_TRAJ_SET_ROTATION = 10226
MT_EMC_TRAJ_SET_G92 = 10227
MT_EMC_TRAJ_CLEAR_PROBE_TRIPPED_FLAG = 10228
MT_EMC_TRAJ_PROBE = 10229
MT_EMC_TRAJ_SET_TELEOP_ENABLE = 10230
MT_EMC_TRAJ_SET_TELEOP_VECTOR = 10231
MT_EMC_TRAJ_SET_SPINDLESYNC = 10232
MT_EMC_TRAJ_SET_SPINDLE_SCALE = 10233
MT_EMC_TRAJ_SET_FO_ENABLE = 10234
MT_EMC_TRAJ_SET_SO_ENABLE = 10235
MT_EMC_TRAJ_SET_FH_ENABLE = 10236
MT_EMC_TRAJ_RIGID_TAP = 10237
MT_EMC_TRAJ_SET_RAPID_SCALE = 10238
MT_EMC_TRAJ_STAT = 10299
MT_EMC_MOTION_INIT = 10301
MT_EMC_MOTION_HALT = 10302
MT_EMC_MOTION_ABORT = 10303
MT_EMC_MOTION_SET_AOUT = 10304
MT_EMC_MOTION_SET_DOUT = 10305
MT_EMC_MOTION_ADAPTIVE = 10306
MT_EMC_SPINDLE_ORIENT = 10317
MT_EMC_SPINDLE_WAIT_ORIENT_COMPLETE = 10318
MT_EMC_MOTION_STAT = 10399
MT_EMC_TASK_INIT = 10501
MT_EMC_TASK_HALT = 10502
MT_EMC_TASK_ABORT = 10503
MT_EMC_TASK_SET_MODE = 10504
MT_EMC_TASK_SET_STATE = 10505
MT_EMC_TASK_PLAN_OPEN = 10506
MT_EMC_TASK_PLAN_RUN = 10507
MT_EMC_TASK_PLAN_READ = 10508
MT_EMC_TASK_PLAN_EXECUTE = 10509
MT_EMC_TASK_PLAN_PAUSE = 10510
MT_EMC_TASK_PLAN_STEP = 10511
MT_EMC_TASK_PLAN_RESUME = 10512
MT_EMC_TASK_PLAN_END = 10513
MT_EMC_TASK_PLAN_CLOSE = 10514
MT_EMC_TASK_PLAN_INIT = 10515
MT_EMC_TASK_PLAN_SYNCH = 10516
MT_EMC_TASK_PLAN_SET_OPTIONAL_STOP = 10517
MT_EMC_TASK_PLAN_SET_BLOCK_DELETE = 10518
MT_EMC_TASK_PLAN_OPTIONAL_STOP = 10519
MT_EMC_TASK_PLAN_RESET = 10520
MT_EMC_TASK_PLAN_REPLY = 10530
MT_EMC_TASK_STAT = 10599
MT_EMC_TOOL_INIT = 11101
MT_EMC_TOOL_HALT = 11102
MT_EMC_TOOL_ABORT = 11103
MT_EMC_TOOL_PREPARE = 11104
MT_EMC_TOOL_LOAD = 11105
MT_EMC_TOOL_UNLOAD = 11106
MT_EMC_TOOL_LOAD_TOOL_TABLE = 11107
MT_EMC_TOOL_SET_OFFSET = 11108
MT_EMC_TOOL_SET_NUMBER = 11109
MT_EMC_TOOL_UPDATE_TOOL_TABLE = 11110
MT_EMC_TOOL_STAT = 11199
MT_EMC_AUX_ESTOP_ON = 11206
MT_EMC_AUX_ESTOP_OFF = 11207
MT_EMC_AUX_ESTOP_RESET = 11208
MT_EMC_AUX_INPUT_WAIT = 11209
MT_EMC_AUX_STAT = 11299
MT_EMC_SPINDLE_ON = 11304
MT_EMC_SPINDLE_OFF = 11305
MT_EMC_SPINDLE_INCREASE = 11309
MT_EMC_SPINDLE_DECREASE = 11310
MT_EMC_SPINDLE_CONSTANT = 11311
MT_EMC_SPINDLE_BRAKE_RELEASE = 11312
MT_EMC_SPINDLE_BRAKE_ENGAGE = 11313
MT_EMC_SPINDLE_SPEED = 11316
MT_EMC_SPINDLE_STAT = 11399
MT_EMC_COOLANT_MIST_ON = 11404
MT_EMC_COOLANT_MIST_OFF = 11405
MT_EMC_COOLANT_FLOOD_ON = 11406
MT_EMC_COOLANT_FLOOD_OFF = 11407
MT_EMC_COOLANT_STAT = 11499
MT_EMC_LUBE_ON = 11504
MT_EMC_LUBE_OFF = 11505
MT_EMC_LUBE_STAT = 11599
MT_EMC_IO_INIT = 11601
MT_EMC_IO_HALT = 11602
MT_EMC_IO_ABORT = 11603
MT_EMC_IO_SET_CYCLE_TIME = 11604
MT_EMC_IO_STAT = 11699
MT_EMC_INIT = 11901
MT_EMC_HALT = 11902
MT_EMC_ABORT = 11903
MT_EMC_STAT = 11999
MT_EMCSTAT_FULL_UPDATE = 12500
MT_EMCSTAT_INCREMENTAL_UPDATE = 12501
MT_EMC_NML_ERROR = 12510
MT_EMC_NML_TEXT = 12511
MT_EMC_NML_DISPLAY = 12512
MT_EMCCMD_EXECUTED = 12520
MT_EMCCMD_COMPLETED = 12521
MT_LAUNCHER_FULL_UPDATE = 12600
MT_LAUNCHER_INCREMENTAL_UPDATE = 12601
MT_LAUNCHER_ERROR = 12602
MT_LAUNCHER_START = 12610
MT_LAUNCHER_TERMINATE = 12611
MT_LAUNCHER_KILL = 12612
MT_LAUNCHER_WRITE_STDIN = 12613
MT_LAUNCHER_CALL = 12614
MT_LAUNCHER_SHUTDOWN = 12615
MT_LAUNCHER_SET = 12616
ORIGIN_UNKNOWN = 0
ORIGIN_G54 = 1
ORIGIN_G55 = 2
ORIGIN_G56 = 3
ORIGIN_G57 = 4
ORIGIN_G58 = 5
ORIGIN_G59 = 6
ORIGIN_G59_1 = 7
ORIGIN_G59_2 = 8
ORIGIN_G59_3 = 9
_EMC_TRAJ_TERM_COND_STOP = 1
_EMC_TRAJ_TERM_COND_BLEND = 2
_CANON_STOPPED = 1
_CANON_CLOCKWISE = 2
_CANON_COUNTERCLOCKWISE = 3
_ANALOG_INPUT = 0
_DIGITAL_INPUT = 1
IMMEDIATE = 0
RISE = 1
FALL = 2
BE_HIGH = 3
BE_LOW = 4
INTERP_IDLE = 1
INTERP_RUNNING = 2
INTERP_SYNC_WAIT = 3
INTERP_PAUSED = 4
INTERP_QUEUE_WAIT = 5
INTERP_ABORT_WAIT = 6
INTERP_STATE_UNSET = 99


DESCRIPTOR.enum_types_by_name['ValueType'] = _VALUETYPE
DESCRIPTOR.enum_types_by_name['HalPinDirection'] = _HALPINDIRECTION
DESCRIPTOR.enum_types_by_name['HalParamDirection'] = _HALPARAMDIRECTION
DESCRIPTOR.enum_types_by_name['HalFunctType'] = _HALFUNCTTYPE
DESCRIPTOR.enum_types_by_name['ObjectType'] = _OBJECTTYPE
DESCRIPTOR.enum_types_by_name['msgidType'] = _MSGIDTYPE
DESCRIPTOR.enum_types_by_name['socketType'] = _SOCKETTYPE
DESCRIPTOR.enum_types_by_name['securityMechanism'] = _SECURITYMECHANISM
DESCRIPTOR.enum_types_by_name['RCS_STATUS'] = _RCS_STATUS
DESCRIPTOR.enum_types_by_name['MsgOrigin'] = _MSGORIGIN
DESCRIPTOR.enum_types_by_name['MsgLevel'] = _MSGLEVEL
DESCRIPTOR.enum_types_by_name['OriginDetail'] = _ORIGINDETAIL
DESCRIPTOR.enum_types_by_name['OriginType'] = _ORIGINTYPE
DESCRIPTOR.enum_types_by_name['Severity'] = _SEVERITY
DESCRIPTOR.enum_types_by_name['StatusType'] = _STATUSTYPE
DESCRIPTOR.enum_types_by_name['ReplyType'] = _REPLYTYPE
DESCRIPTOR.enum_types_by_name['ServiceType'] = _SERVICETYPE
DESCRIPTOR.enum_types_by_name['ServiceAPI'] = _SERVICEAPI
DESCRIPTOR.enum_types_by_name['ContainerType'] = _CONTAINERTYPE
DESCRIPTOR.enum_types_by_name['OriginIndex'] = _ORIGININDEX
DESCRIPTOR.enum_types_by_name['TermConditionType'] = _TERMCONDITIONTYPE
DESCRIPTOR.enum_types_by_name['CanonDirection'] = _CANONDIRECTION
DESCRIPTOR.enum_types_by_name['InputType'] = _INPUTTYPE
DESCRIPTOR.enum_types_by_name['WaitType'] = _WAITTYPE
DESCRIPTOR.enum_types_by_name['InterpreterStateType'] = _INTERPRETERSTATETYPE


# @@protoc_insertion_point(module_scope)
